<?php
namespace app\daohang\loglic;

class Category
{
    /**
    * 定义栏目模型的字段
    * @version 1.0.0 首次引入
    * @param array $data 可选;初始数据;默认：空
    * @return array 表格列字段属性（DcBuildTable）
    */
    public function fields($data)
    {
        return [
            'html_1' => [
                'order'           => 0,
                'type'            => 'html',
                'value'           => '<div class="row"><div class="col-12 col-md-8">',
            ],
            'term_module' => [
                'order'           => 0,
                'type'            => 'hidden',
                'value'           => 'daohang',
            ],
            'term_controll' => [
                'order'           => 0,
                'type'            => 'hidden',
                'value'           => 'category',
            ],
            'term_type' => [
                'order'           => 0,
                'type'            => 'hidden',
                'value'           => 'category',
            ],
            'term_id' => [
                'order'           => 1,
                'type'            => 'hidden',
                'value'           => $data['term_id'],
                'data-filter'     => false,
                'data-visible'    => true,
                'data-width'      => 80,
                'data-width-unit' => 'px',
                'data-sortable'   => true,
            ],
            'term_name' => [
                'order'           => 2,
                'type'            => 'text',
                'value'           => $data['term_name'],
                'required'        => true,
                'data-filter'     => false,
                'data-visible'    => true,
                'data-align'      => 'left',
            ],
            'term_slug' => [
                'order'           => 3,
                'type'            => 'text',
                'value'           => $data['term_slug'],
                'data-width'      => 200,
                'data-width-unit' => 'px',
                'data-filter'     => false,
                'data-visible'    => true,
                'data-align'      => 'left',
            ],
            'term_image' => [
                'order'           => 4,
                'type'            => 'image',
                'value'           => $data['term_image'],
                'title'           => lang('dh_term_image'),
            ],
            'term_title' => [
                'order'           => 5,
                'type'            => 'text',
                'value'           => $data['term_title'],
                'title'           => lang('dh_term_title'),
            ],
            'term_keywords' => [
                'order'           => 6,
                'type'            => 'text',
                'value'           => $data['term_keywords'],
                'title'           => lang('dh_term_keywords'),
            ],
            'term_description' => [
                'order'           => 7,
                'type'            => 'text',
                'value'           => $data['term_description'],
                'title'           => lang('dh_term_description'),
            ],
            'term_info' => [
                'order'           => 8,
                'type'            => 'textarea',
                'value'           => $data['term_info'],
                'rows'            => 4,
            ],
            'html_2'      => [
                'order'           => 9,
                'type'            => 'html',
                'value'           => '</div><div class="col-12 col-md-4">',
            ],
            'term_parent' => [
                'order'           => 10,
                'type'            => 'select',
                'value'           => $data['term_parent'],
                'option'          => DcTermOption(['module'=>['eq','daohang']]),
                'data-width'      => 100,
                'data-filter'     => false,
                'data-visible'    => true,
            ],
            'term_status' => [
                'order'           => 11,
                'type'            => 'select',
                'value'           => DcEmpty($data['term_status'],'normal'),
                'option'          => ['normal'=>lang('normal'),'hidden'=>lang('hidden'),'private'=>lang('private')],
                'data-filter'     => true,
                'data-visible'    => false,
            ],
            'term_status_text' => [
                'order'           => 11,
                'data-title'      => lang('term_status'),
                'data-visible'    => true,
                'data-width'      => 100,
            ],
            'term_navbar'=> [
                'order'            => 12,
                'type'             => 'custom',
                'value'            => $data['term_navbar'],
                'option'           => ['no'=>'no','yes'=>'yes'],
                'title'            => lang('dh_term_navbar'),
                'data-title'       => lang('dh_term_navbar'),
                'data-visible'     => true,
                'data-width'       => 100,
            ],
            'term_action' => [
                'order'           => 14,
                'type'            => 'select',
                'value'           => DcEmpty($data['term_action'],'index'),
                'option'          => ['index'=>lang('dh_option_index'),'channel'=>lang('dh_option_channel'),'page'=>lang('dh_option_page')],
                'data-width'      => 100,
                'data-filter'     => true,
                'data-visible'    => true,
            ],
            'term_count' => [
                'order'           => 15,
                'data-visible'    => true,
                'data-sortable'   => true,
                'data-width'      => '100',
            ],
            'term_order' => [
                'order'           => 16,
                'type'            => 'number',
                'value'           => intval($data['term_order']),
                'data-filter'     => false,
                'data-visible'    => true,
                'data-width'      => '100',
                'data-sortable'   => true,
            ],
            'term_tpl'   => [
                'order'            => 17,
                'type'             => 'text',
                'value'            => $data['term_tpl'],
            ],
            'term_limit'   => [
                'order'            => 0,
                'type'             => 'text',
                'value'            => $data['term_limit'],
                'title'            => lang('dh_term_limit'),
                'placeholder'      => lang('dh_term_limit_category'),
            ],
            'html_3' => [
                'order'            => 18,
                'type'             => 'html',
                'value'            => '</div></div>',
            ]
        ];
    }
    
    /**
    * 按内容模型获取分类关系
    * @version 1.2.0 首次引入
    * @param array $data 可选;初始数据;默认：空
    * @return array key=>value格式
    */
    public function option(){
        $item = daohangCategorySelect([
            'result'   => 'array',
            'module'   => 'daohang',
            //'controll' => 'category',
            'action'   => 'index',
            'with'     => '',
            'field'    => 'term_id,term_name',
        ]);
        $option = [];
        foreach($item as $key=>$value){
            $option[$value['term_id']] = $value['term_name'];
        }
        return $option;
    }
    
    //所有扩展字段
    public function metaFieldsKey()
    {
        $array = array_merge(array_keys(config('custom_fields.term_meta')),config('daohang.meta_category'));
        return array_unique($array);
    }
}